import cv2
import numpy as np
import math


def getPencilLines(img):
    # STEPS:
    # Convert img from BGR to HSV color space
    # Get binary mask corresponding to all pixels within range of the min and max thresholds
    # Find edges with the Canny edge detection algorithm
    # Blur the edges
    # Perform Hough transform and return the lines array

    # Color thresholds in HSV
    HSV_MIN = np.array([70, 20, 20])
    HSV_MAX = np.array([130, 255, 255])

    # Write your code here


def drawLines(img, lines):
    # Draw lines on an image
    for line in lines:
        rho, theta = line[0]
        a = np.cos(theta)
        b = np.sin(theta)
        x0 = a * rho
        y0 = b * rho
        x1 = int(x0 + 2000 * (-b))
        y1 = int(y0 + 2000 * (a))
        x2 = int(x0 - 2000 * (-b))
        y2 = int(y0 - 2000 * (a))
        cv2.line(img, (x1, y1), (x2, y2), (0, 0, 255), 2)


def main():
    cap = cv2.VideoCapture(0)

    while True:
        # Grab a frame from the stream
        ret, frame = cap.read()

        # Resize the frame to 960 x 540
        frame = cv2.resize(frame, (960, 540), interpolation=cv2.INTER_LINEAR)

        # Show the resized image
        cv2.imshow("Original", frame)

        # Get lines
        lines = getPencilLines(frame)

        thetaMedian = None

        if lines is not None:
            # Draw lines on the original image
            drawLines(frame, lines)

            # Find median angle
            thetaArr = lines[:, 0, 1]  # NumPy slicing
            thetaMedian = np.median(thetaArr)

        print(f'Th = {"None" if thetaMedian is None else math.degrees(thetaMedian)}')

        cv2.imshow('Lines', frame)

        if cv2.waitKey(1) == ord('q'):
            break

    cap.release()
    cv2.destroyAllWindows()


main()



